package Perinci::Sub::To::Text::I18N;

use parent 'Perinci::Sub::To::FuncBase::I18N';

our $VERSION = '0.29'; # VERSION

1;
# ABSTRACT: Project class for Perinci::Sub::To::Text

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Sub::To::Text::I18N - Project class for Perinci::Sub::To::Text

=head1 VERSION

version 0.29

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-To-Text>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-To-Text>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-To-Text>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
